@@ -218,7 +218,7 @@ class Thing:
     def record_type(self):
         '''
         '''
-        return self.get('schema:@type')
+        return self.get('@type')
 
     @record_type.setter
     def record_type(self, value):
@@ -229,20 +229,20 @@ class Thing:
             self.set('schema:object', Thing())
             self.set('schema:instrument', Thing())
         
-        return self.set('schema:@type', value)
+        return self.set('@type', value)
 
     #record_id
     @property
     def record_id(self):
         '''
         '''
-        return self.get('schema:@id')
+        return self.get('@id')
 
     @record_id.setter
     def record_id(self, value):
         '''
         '''
-        return self.set('schema:@id', value)
+        return self.set('@id', value)
 
 
 
